<?php

class CategoryController extends Controller
{
	/**
	 * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
	 * using two-column layout. See 'protected/views/layouts/column2.php'.
	 */
	public $layout='forum';

	/**
	 * @return array action filters
	 */
	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
		);
	}

	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */

	public function allowedActions()
	{
		return 'updatePos';		
	}
	/**
	 * Displays a particular model.
	 * @param integer $id the ID of the model to be displayed
	 */
	public function actionView($id)
	{
		//if you are not a moderator we do not want to diplay the trashbin
		if(!SForumModule::moderator() && $id==1)		
			throw new CHttpException(404,'The requested page does not exist.');

		$model = $this->loadModel($id);
        $models = Category::model()->public()->findAll();
        $dataProvider=new CActiveDataProvider(Category::model()->public());
        $renderOptions = array(
        	'model'=>$model,
			'models'=>$models,
			'dataProvider'=>$dataProvider,
			);
        if(Yii::app()->request->isAjaxRequest)
        {
			echo CJSON::encode(array('status'=>'success','view'=>$this->renderPartial('view',$renderOptions,true)));
		}else{
			$this->render('view',$renderOptions);
		}
	}


	/**
	 * Creates a new model.
	 * If creation is successful, the browser will be redirected to the 'view' page.
	 */
	public function actionCreate()
	{
		$model=new Category;


		if(isset($_POST['Category']))
		{
			$model->attributes=$_POST['Category'];
			if($model->save())
			{
				echo CJSON::encode(array('status'=>'success'));
				return;		
			}
		}

			$this->renderPartial('create',array(
				'model'=>$model,
			));
	}

	/**
	 * Updates a particular model.
	 * If update is successful, the browser will be redirected to the 'view' page.
	 * @param integer $id the ID of the model to be updated
	 */
	public function actionUpdate($id)
	{
		$model=$this->loadModel($id);

		if(isset($_POST['Category']))
		{
			$model->attributes=$_POST['Category'];
			if($model->save())
			{
				echo CJSON::encode(array('status'=>'success'));
				return;		
			}
		}

		$this->renderPartial('update',array(
			'model'=>$model,
		));
	}

	/**
	 * Deletes a particular model.
	 * If deletion is successful, the browser will be redirected to the 'admin' page.
	 * @param integer $id the ID of the model to be deleted
	 */
	public function actionDelete($id)
	{
		
			// we only allow deletion via POST request
			$this->loadModel($id)->delete();

			// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
			if(!isset($_GET['ajax']))
				$this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
	}

	/**
	 * Lists all models.
	 */
	public function actionIndex()
	{
	
		$dataProvider=new CActiveDataProvider(Category::model()->public());
		$this->render('index',array(
			'dataProvider'=>$dataProvider,
		));
	}

	/**
	 * Manages all models.
	 */
	public function actionAdmin()
	{
		$models= Category::model()->public()->findAll();

		$renderOptions = array('models'=>$models);
        if(Yii::app()->request->isAjaxRequest)
        {
			echo CJSON::encode(array('status'=>'success','view'=>$this->renderPartial('admin',$renderOptions,true)));
		}else{
			$this->render('admin',$renderOptions);
		}
		
	}

	public function actionupdatePos ()
	{
		if ( Yii::app()->request->isAjaxRequest )
		{	
			$pos = 1;
			 foreach ( $_POST['pos'] as $id )
			 {
				if ($id=="")
					continue;
				$model = $this->loadModel($id);
				$model->position = $pos;
				$model->save();
				$pos = $pos+1;
			}
		
	
		}
		echo CJSON::encode ( array ('status'=>'success'));

	}
	/**
	 * Returns the data model based on the primary key given in the GET variable.
	 * If the data model is not found, an HTTP exception will be raised.
	 * @param integer the ID of the model to be loaded
	 */
	public function loadModel($id)
	{
		$model=Category::model()->findByPk($id);
		if($model===null )
			throw new CHttpException(404,'The requested page does not exist.');
		return $model;
	}

}
