<?php

/**
 * This is the model class for table "{{category}}".
 *
 * The followings are the available columns in table '{{category}}':
 * @property string $id
 * @property string $name
 */
class Category extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return Category the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{category}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('name','required'),
			array('name', 'length', 'max'=>200),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, name', 'safe', 'on'=>'search'),
		);
	}



	public function scopes()
	{
		return array(
			'trashbin'=>array('condition'=>'name="trashbin"'),
			'public'=>array('condition'=>'name  <> "trashbin"','order'=>'position'),
			);
	}

	//Why not a relation? well We want all topics in the category, but we want to sort by the latest comment but not fetch the comments themselves
	//This is probably possible with scopes but ddint get it to work so feel free to pm improvements.
	public function getTopics()
	{
		$topics = Topic::model()->with(
			array('comments'=>array('select'=>false,'order'=>'comments.created DESC')))->findAll('category='.$this->id.' AND sticky=0');
		return $topics;
	}

	public function getStickyTopics()
	{
		$topics = Topic::model()->sticky()->with
			(array('comments'=>array('select'=>false,'order'=>'comments.created DESC')))->findAll('category='.$this->id);
		return $topics;
	}

	public static function getListData($type=""){

		$categories = Category::model()->findAll('',array('ORDER'=>'name'));
		if(($type="ajax")){
			echo CJSON::encode(CHtml::listData($categories, 'id', 'name'));
		}else{
			return CHtml::listData($categories, 'id', 'name'); // Get the list of options
		}
	}
	public static function getListOptions($selection){
		$categories = Category::model()->public()->findAll('',array('ORDER'=>'name'));
		return CHtml::listOptions($selection,array('id','name'),array()); // Get the list of options

	}
	public function getUrl()
	{
		 return Yii::app()->createUrl('/sforum/category/view', array('id'=>$this->id,'name'=>$this->name));
	}
	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'name' => 'Name',
		);
	}
	public function getTopicCount()
	{
		return Topic::model()->count('category='.$this->id.' AND status=1');
	}



	public function getLatestTopics(){
		$criteria = new CDbCriteria(
		array(
			'order'=>'created DESC',
			'limit'=>6,
			'condition'=>'category="'.$this->id.'"',
		));
		return Topic::model()->findAll($criteria);
	
	}
	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id,true);
		$criteria->compare('name',$this->name,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
}